@@ -24,21 +24,22 @@
 
 class QMaemo5ListPickSelector;
 
-class ConnectDialog : public QDialog {
-	Q_OBJECT
+class ConnectDialog : public QDialog
+{
+    Q_OBJECT
 public:
-	ConnectDialog(QWidget *parent);
+    ConnectDialog(QWidget *parent);
 public slots:
-	virtual void accept();
+    virtual void accept();
 signals:
-	void connectToHost(QString url, int quality, int listen_port);
+    void connectToHost(QString url, int quality, int listen_port, bool view_only);
 private slots:
-	void hostnameUpdated(QString newtext);
+    void hostnameUpdated(QString newtext);
 private:
-	QHBoxLayout layout;
-	QStringList hostnames_sorted;
-	QPushButton *done;
-	QComboBox hosts;
-	QMaemo5ListPickSelector *quality_selector;
+    QStringList hostnames_sorted;
+    QPushButton done;
+    QComboBox hosts;
+    QComboBox quality_combobox;
+    QCheckBox viewonly;
 };
 #endif
