@@ -27,10 +27,9 @@
 #include "remoteview.h"
 #include "vncclientthread.h"
 
-class KConfigGroup{};
+class KConfigGroup {};
 
 #include <QClipboard>
-#include <QTextEdit>
 
 extern "C" {
 #include <rfb/rfbclient.h>
@@ -44,22 +43,23 @@ public:
     explicit VncView(QWidget *parent = 0, const KUrl &url = KUrl(), RemoteView::Quality quality = RemoteView::Medium, int listen_port = 0);
     ~VncView();
 
-    QSize framebufferSize();
+    QSize framebufferSize() const;
     QSize sizeHint() const;
     QSize minimumSizeHint() const;
-    bool isQuitting();
-    qreal zoomFactor() { return m_horizontalFactor;} //assumes fixed aspect ratio
+    bool isQuitting() const;
+    qreal zoomFactor() const { return m_horizontalFactor;} //assumes fixed aspect ratio
     void reloadSettings();
     bool start();
     bool supportsScaling() const;
     bool supportsLocalCursor() const;
-    
+
     void setQuality(int q);
     void setViewOnly(bool viewOnly);
     void showDotCursor(DotCursorState state);
     void useFastTransformations(bool enabled);
-    QPoint cursorPosition() { return QPoint(cursor_x, cursor_y); }
-    
+    QPoint cursorPosition() const { return QPoint(cursor_x, cursor_y); }
+    void setDisplayOff(bool off) { display_off = off; }
+
 public slots:
     void setZoomLevel(int level = -1); //'level' doesn't correspond to actual magnification, though mapping is done here
     void sendKey(Qt::Key key);
@@ -91,13 +91,14 @@ private:
     int left_zoom, right_zoom;
     bool disable_tapping;
     RemoteView::Quality quality;
-	int listen_port;
-	Qt::TransformationMode transformation_mode;
+    int listen_port;
+    Qt::TransformationMode transformation_mode;
+    bool display_off;
 
     void keyEventHandler(QKeyEvent *e);
     void unpressModifiers();
     void wheelEventHandler(QWheelEvent *event);
-    
+
 private slots:
     void mouseEventHandler(QMouseEvent *event = 0);
 
